Type

Enum Type 

#[repr(i32)]
pub enum Type {
Show 51 variants Connect = 2, Connected = 3, Subscribe = 4, Producer = 5, Send = 6, SendReceipt = 7, SendError = 8, Message = 9, Ack = 10, Flow = 11, Unsubscribe = 12, Success = 13, Error = 14, CloseProducer = 15, CloseConsumer = 16, ProducerSuccess = 17, Ping = 18, Pong = 19, RedeliverUnacknowledgedMessages = 20, PartitionedMetadata = 21, PartitionedMetadataResponse = 22, Lookup = 23, LookupResponse = 24, ConsumerStats = 25, ConsumerStatsResponse = 26, ReachedEndOfTopic = 27, Seek = 28, GetLastMessageId = 29, GetLastMessageIdResponse = 30, ActiveConsumerChange = 31, GetTopicsOfNamespace = 32, GetTopicsOfNamespaceResponse = 33, GetSchema = 34, GetSchemaResponse = 35, AuthChallenge = 36, AuthResponse = 37, AckResponse = 38, GetOrCreateSchema = 39, GetOrCreateSchemaResponse = 40, NewTxn = 50, NewTxnResponse = 51, AddPartitionToTxn = 52, AddPartitionToTxnResponse = 53, AddSubscriptionToTxn = 54, AddSubscriptionToTxnResponse = 55, EndTxn = 56, EndTxnResponse = 57, EndTxnOnPartition = 58, EndTxnOnPartitionResponse = 59, EndTxnOnSubscription = 60, EndTxnOnSubscriptionResponse = 61,
}

Variants



Connect = 2



Connected = 3



Subscribe = 4



Producer = 5



Send = 6



SendReceipt = 7



SendError = 8



Message = 9



Ack = 10



Flow = 11



Unsubscribe = 12



Success = 13



Error = 14



CloseProducer = 15



CloseConsumer = 16



ProducerSuccess = 17



Ping = 18



Pong = 19



RedeliverUnacknowledgedMessages = 20



PartitionedMetadata = 21



PartitionedMetadataResponse = 22



Lookup = 23



LookupResponse = 24



ConsumerStats = 25



ConsumerStatsResponse = 26



ReachedEndOfTopic = 27



Seek = 28



GetLastMessageId = 29



GetLastMessageIdResponse = 30



ActiveConsumerChange = 31



GetTopicsOfNamespace = 32



GetTopicsOfNamespaceResponse = 33



GetSchema = 34



GetSchemaResponse = 35



AuthChallenge = 36



AuthResponse = 37



AckResponse = 38



GetOrCreateSchema = 39



GetOrCreateSchemaResponse = 40



NewTxn = 50

transaction related



NewTxnResponse = 51



AddPartitionToTxn = 52



AddPartitionToTxnResponse = 53



AddSubscriptionToTxn = 54



AddSubscriptionToTxnResponse = 55



EndTxn = 56



EndTxnResponse = 57



EndTxnOnPartition = 58



EndTxnOnPartitionResponse = 59



EndTxnOnSubscription = 60



EndTxnOnSubscriptionResponse = 61

Implementations

Source

impl Type

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of Type.

pub fn from_i32(value: i32) -> Option<Type>

Converts an i32 to a Type, or None if value is not a valid variant.