#[repr(i32)]pub enum ProducerAccessMode {
Shared = 0,
Exclusive = 1,
WaitForExclusive = 2,
ExclusiveWithFencing = 3,
}Variants
By default multiple producers can publish on a topic
Exclusive = 1
Require exclusive access for producer. Fail immediately if there’s already a producer connected.
WaitForExclusive = 2
Producer creation is pending until it can acquire exclusive access
ExclusiveWithFencing = 3
Require exclusive access for producer. Fence out old producer.
Implementations
Sourceimpl ProducerAccessMode
impl ProducerAccessMode
Sourcepub fn from_i32(value: i32) -> Option<ProducerAccessMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProducerAccessMode>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProducerAccessMode, or None if value is not a valid variant.
Sourceimpl ProducerAccessMode
impl ProducerAccessMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.