#[repr(i32)]pub enum ProtocolVersion {
Show 16 variants
V0 = 0,
V1 = 1,
V2 = 2,
V3 = 3,
V4 = 4,
V5 = 5,
V6 = 6,
V7 = 7,
V8 = 8,
V9 = 9,
V10 = 10,
V11 = 11,
V12 = 12,
V13 = 13,
V14 = 14,
V15 = 15,
}Expand description
Each protocol version identify new features that are incrementally added to the protocol
Variants
V0 = 0
Initial versioning
V1 = 1
Added application keep-alive
V2 = 2
Added RedeliverUnacknowledgedMessages Command
V3 = 3
Added compression with LZ4 and ZLib
V4 = 4
Added batch message support
V5 = 5
Added disconnect client w/o closing connection
V6 = 6
Added checksum computation for metadata + payload
V7 = 7
Added CommandLookupTopic - Binary Lookup
V8 = 8
Added CommandConsumerStats - Client fetches broker side consumer stats
V9 = 9
Added end of topic notification
V10 = 10
Added proxy to broker
V11 = 11
C++ consumers before this version are not correctly handling the checksum field
V12 = 12
Added get topic’s last messageId from broker
V13 = 13
Added CommandActiveConsumerChange Added CommandGetTopicsOfNamespace
Schema-registry : added avro schema format for json
V14 = 14
Add CommandAuthChallenge and CommandAuthResponse for mutual auth
V15 = 15
Added Key_Shared subscription
Add CommandGetOrCreateSchema and CommandGetOrCreateSchemaResponse
Implementations