Struct BaseCommand

pub struct BaseCommand {
Show 54 fields pub type: i32, pub connect: Option<CommandConnect>, pub connected: Option<CommandConnected>, pub subscribe: Option<CommandSubscribe>, pub producer: Option<CommandProducer>, pub send: Option<CommandSend>, pub send_receipt: Option<CommandSendReceipt>, pub send_error: Option<CommandSendError>, pub message: Option<CommandMessage>, pub ack: Option<CommandAck>, pub flow: Option<CommandFlow>, pub unsubscribe: Option<CommandUnsubscribe>, pub success: Option<CommandSuccess>, pub error: Option<CommandError>, pub close_producer: Option<CommandCloseProducer>, pub close_consumer: Option<CommandCloseConsumer>, pub producer_success: Option<CommandProducerSuccess>, pub ping: Option<CommandPing>, pub pong: Option<CommandPong>, pub redeliver_unacknowledged_messages: Option<CommandRedeliverUnacknowledgedMessages>, pub partition_metadata: Option<CommandPartitionedTopicMetadata>, pub partition_metadata_response: Option<CommandPartitionedTopicMetadataResponse>, pub lookup_topic: Option<CommandLookupTopic>, pub lookup_topic_response: Option<CommandLookupTopicResponse>, pub consumer_stats: Option<CommandConsumerStats>, pub consumer_stats_response: Option<CommandConsumerStatsResponse>, pub reached_end_of_topic: Option<CommandReachedEndOfTopic>, pub seek: Option<CommandSeek>, pub get_last_message_id: Option<CommandGetLastMessageId>, pub get_last_message_id_response: Option<CommandGetLastMessageIdResponse>, pub active_consumer_change: Option<CommandActiveConsumerChange>, pub get_topics_of_namespace: Option<CommandGetTopicsOfNamespace>, pub get_topics_of_namespace_response: Option<CommandGetTopicsOfNamespaceResponse>, pub get_schema: Option<CommandGetSchema>, pub get_schema_response: Option<CommandGetSchemaResponse>, pub auth_challenge: Option<CommandAuthChallenge>, pub auth_response: Option<CommandAuthResponse>, pub ack_response: Option<CommandAckResponse>, pub get_or_create_schema: Option<CommandGetOrCreateSchema>, pub get_or_create_schema_response: Option<CommandGetOrCreateSchemaResponse>, pub new_txn: Option<CommandNewTxn>, pub new_txn_response: Option<CommandNewTxnResponse>, pub add_partition_to_txn: Option<CommandAddPartitionToTxn>, pub add_partition_to_txn_response: Option<CommandAddPartitionToTxnResponse>, pub add_subscription_to_txn: Option<CommandAddSubscriptionToTxn>, pub add_subscription_to_txn_response: Option<CommandAddSubscriptionToTxnResponse>, pub end_txn: Option<CommandEndTxn>, pub end_txn_response: Option<CommandEndTxnResponse>, pub end_txn_on_partition: Option<CommandEndTxnOnPartition>, pub end_txn_on_partition_response: Option<CommandEndTxnOnPartitionResponse>, pub end_txn_on_subscription: Option<CommandEndTxnOnSubscription>, pub end_txn_on_subscription_response: Option<CommandEndTxnOnSubscriptionResponse>, pub tc_client_connect_request: Option<CommandTcClientConnectRequest>, pub tc_client_connect_response: Option<CommandTcClientConnectResponse>,
}

Fields

type: i32connect: Option<CommandConnect>connected: Option<CommandConnected>subscribe: Option<CommandSubscribe>producer: Option<CommandProducer>send: Option<CommandSend>send_receipt: Option<CommandSendReceipt>send_error: Option<CommandSendError>message: Option<CommandMessage>ack: Option<CommandAck>flow: Option<CommandFlow>unsubscribe: Option<CommandUnsubscribe>success: Option<CommandSuccess>error: Option<CommandError>close_producer: Option<CommandCloseProducer>close_consumer: Option<CommandCloseConsumer>producer_success: Option<CommandProducerSuccess>ping: Option<CommandPing>pong: Option<CommandPong>redeliver_unacknowledged_messages: Option<CommandRedeliverUnacknowledgedMessages>partition_metadata: Option<CommandPartitionedTopicMetadata>partition_metadata_response: Option<CommandPartitionedTopicMetadataResponse>lookup_topic: Option<CommandLookupTopic>lookup_topic_response: Option<CommandLookupTopicResponse>consumer_stats: Option<CommandConsumerStats>consumer_stats_response: Option<CommandConsumerStatsResponse>reached_end_of_topic: Option<CommandReachedEndOfTopic>seek: Option<CommandSeek>get_last_message_id: Option<CommandGetLastMessageId>get_last_message_id_response: Option<CommandGetLastMessageIdResponse>active_consumer_change: Option<CommandActiveConsumerChange>get_topics_of_namespace: Option<CommandGetTopicsOfNamespace>get_topics_of_namespace_response: Option<CommandGetTopicsOfNamespaceResponse>get_schema: Option<CommandGetSchema>get_schema_response: Option<CommandGetSchemaResponse>auth_challenge: Option<CommandAuthChallenge>auth_response: Option<CommandAuthResponse>ack_response: Option<CommandAckResponse>get_or_create_schema: Option<CommandGetOrCreateSchema>get_or_create_schema_response: Option<CommandGetOrCreateSchemaResponse>new_txn: Option<CommandNewTxn>

transaction related

new_txn_response: Option<CommandNewTxnResponse>add_partition_to_txn: Option<CommandAddPartitionToTxn>add_partition_to_txn_response: Option<CommandAddPartitionToTxnResponse>add_subscription_to_txn: Option<CommandAddSubscriptionToTxn>add_subscription_to_txn_response: Option<CommandAddSubscriptionToTxnResponse>end_txn: Option<CommandEndTxn>end_txn_response: Option<CommandEndTxnResponse>end_txn_on_partition: Option<CommandEndTxnOnPartition>end_txn_on_partition_response: Option<CommandEndTxnOnPartitionResponse>end_txn_on_subscription: Option<CommandEndTxnOnSubscription>end_txn_on_subscription_response: Option<CommandEndTxnOnSubscriptionResponse>tc_client_connect_request: Option<CommandTcClientConnectRequest>tc_client_connect_response: Option<CommandTcClientConnectResponse>

Implementations

Source

impl BaseCommand

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.