pub struct CommandAck {
pub consumer_id: u64,
pub ack_type: i32,
pub message_id: Vec<MessageIdData>,
pub validation_error: Option<i32>,
pub properties: Vec<KeyLongValue>,
pub txnid_least_bits: Option<u64>,
pub txnid_most_bits: Option<u64>,
pub request_id: Option<u64>,
}Fields
consumer_id: u64ack_type: i32message_id: Vec<MessageIdData>In case of individual acks, the client can pass a list of message ids
validation_error: Option<i32>properties: Vec<KeyLongValue>txnid_least_bits: Option<u64>txnid_most_bits: Option<u64>request_id: Option<u64>Implementations
Sourceimpl CommandAck
impl CommandAck
Sourcepub fn ack_type(&self) -> AckType
pub fn ack_type(&self) -> AckType
Returns the enum value of ack_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_ack_type(&mut self, value: AckType)
pub fn set_ack_type(&mut self, value: AckType)
Sets ack_type to the provided enum value.
Sourcepub fn validation_error(&self) -> ValidationError
pub fn validation_error(&self) -> ValidationError
Returns the enum value of validation_error, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_validation_error(&mut self, value: ValidationError)
pub fn set_validation_error(&mut self, value: ValidationError)
Sets validation_error to the provided enum value.
Sourcepub fn txnid_least_bits(&self) -> u64
pub fn txnid_least_bits(&self) -> u64
Returns the value of txnid_least_bits, or the default value if txnid_least_bits is unset.
Sourcepub fn txnid_most_bits(&self) -> u64
pub fn txnid_most_bits(&self) -> u64
Returns the value of txnid_most_bits, or the default value if txnid_most_bits is unset.
Sourcepub fn request_id(&self) -> u64
pub fn request_id(&self) -> u64
Returns the value of request_id, or the default value if request_id is unset.