pub struct CommandAckResponse {
pub consumer_id: u64,
pub txnid_least_bits: Option<u64>,
pub txnid_most_bits: Option<u64>,
pub error: Option<i32>,
pub message: Option<String>,
pub request_id: Option<u64>,
}Fields
consumer_id: u64txnid_least_bits: Option<u64>txnid_most_bits: Option<u64>error: Option<i32>message: Option<String>request_id: Option<u64>Implementations
Sourceimpl CommandAckResponse
impl CommandAckResponse
Sourcepub fn txnid_least_bits(&self) -> u64
pub fn txnid_least_bits(&self) -> u64
Returns the value of txnid_least_bits, or the default value if txnid_least_bits is unset.
Sourcepub fn txnid_most_bits(&self) -> u64
pub fn txnid_most_bits(&self) -> u64
Returns the value of txnid_most_bits, or the default value if txnid_most_bits is unset.
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn request_id(&self) -> u64
pub fn request_id(&self) -> u64
Returns the value of request_id, or the default value if request_id is unset.