CommandConnect

Struct CommandConnect 

pub struct CommandConnect {
    pub client_version: String,
    pub auth_method: Option<i32>,
    pub auth_method_name: Option<String>,
    pub auth_data: Option<Vec<u8>>,
    pub protocol_version: Option<i32>,
    pub proxy_to_broker_url: Option<String>,
    pub original_principal: Option<String>,
    pub original_auth_data: Option<String>,
    pub original_auth_method: Option<String>,
    pub feature_flags: Option<FeatureFlags>,
}

Fields

client_version: Stringauth_method: Option<i32>

Deprecated. Use “auth_method_name” instead.

auth_method_name: Option<String>auth_data: Option<Vec<u8>>protocol_version: Option<i32>proxy_to_broker_url: Option<String>

Client can ask to be proxyied to a specific broker This is only honored by a Pulsar proxy

original_principal: Option<String>

Original principal that was verified by a Pulsar proxy. In this case the auth info above will be the auth of the proxy itself

original_auth_data: Option<String>

Original auth role and auth Method that was passed to the proxy. In this case the auth info above will be the auth of the proxy itself

original_auth_method: Option<String>feature_flags: Option<FeatureFlags>

Feature flags

Implementations

Source

impl CommandConnect

pub fn auth_method(&self) -> AuthMethod

Returns the enum value of auth_method, or the default if the field is unset or set to an invalid enum value.

pub fn set_auth_method(&mut self, value: AuthMethod)

Sets auth_method to the provided enum value.

pub fn auth_data(&self) -> &[u8]

Returns the value of auth_data, or the default value if auth_data is unset.

pub fn protocol_version(&self) -> i32

Returns the value of protocol_version, or the default value if protocol_version is unset.

pub fn auth_method_name(&self) -> &str

Returns the value of auth_method_name, or the default value if auth_method_name is unset.

pub fn proxy_to_broker_url(&self) -> &str

Returns the value of proxy_to_broker_url, or the default value if proxy_to_broker_url is unset.

pub fn original_principal(&self) -> &str

Returns the value of original_principal, or the default value if original_principal is unset.

pub fn original_auth_data(&self) -> &str

Returns the value of original_auth_data, or the default value if original_auth_data is unset.

pub fn original_auth_method(&self) -> &str

Returns the value of original_auth_method, or the default value if original_auth_method is unset.