pub struct CommandConsumerStatsResponse {Show 15 fields
pub request_id: u64,
pub error_code: Option<i32>,
pub error_message: Option<String>,
pub msg_rate_out: Option<f64>,
pub msg_throughput_out: Option<f64>,
pub msg_rate_redeliver: Option<f64>,
pub consumer_name: Option<String>,
pub available_permits: Option<u64>,
pub unacked_messages: Option<u64>,
pub blocked_consumer_on_unacked_msgs: Option<bool>,
pub address: Option<String>,
pub connected_since: Option<String>,
pub type: Option<String>,
pub msg_rate_expired: Option<f64>,
pub msg_backlog: Option<u64>,
}Fields
request_id: u64error_code: Option<i32>error_message: Option<String>msg_rate_out: Option<f64>msg_throughput_out: Option<f64>msg_rate_redeliver: Option<f64>consumer_name: Option<String>available_permits: Option<u64>unacked_messages: Option<u64>blocked_consumer_on_unacked_msgs: Option<bool>address: Option<String>connected_since: Option<String>type: Option<String>msg_rate_expired: Option<f64>msg_backlog: Option<u64>Implementations
Sourceimpl CommandConsumerStatsResponse
impl CommandConsumerStatsResponse
Sourcepub fn error_code(&self) -> ServerError
pub fn error_code(&self) -> ServerError
Returns the enum value of error_code, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error_code(&mut self, value: ServerError)
pub fn set_error_code(&mut self, value: ServerError)
Sets error_code to the provided enum value.
Sourcepub fn error_message(&self) -> &str
pub fn error_message(&self) -> &str
Returns the value of error_message, or the default value if error_message is unset.
Sourcepub fn msg_rate_out(&self) -> f64
pub fn msg_rate_out(&self) -> f64
Returns the value of msg_rate_out, or the default value if msg_rate_out is unset.
Sourcepub fn msg_throughput_out(&self) -> f64
pub fn msg_throughput_out(&self) -> f64
Returns the value of msg_throughput_out, or the default value if msg_throughput_out is unset.
Sourcepub fn msg_rate_redeliver(&self) -> f64
pub fn msg_rate_redeliver(&self) -> f64
Returns the value of msg_rate_redeliver, or the default value if msg_rate_redeliver is unset.
Sourcepub fn consumer_name(&self) -> &str
pub fn consumer_name(&self) -> &str
Returns the value of consumer_name, or the default value if consumer_name is unset.
Sourcepub fn available_permits(&self) -> u64
pub fn available_permits(&self) -> u64
Returns the value of available_permits, or the default value if available_permits is unset.
Sourcepub fn unacked_messages(&self) -> u64
pub fn unacked_messages(&self) -> u64
Returns the value of unacked_messages, or the default value if unacked_messages is unset.
Sourcepub fn blocked_consumer_on_unacked_msgs(&self) -> bool
pub fn blocked_consumer_on_unacked_msgs(&self) -> bool
Returns the value of blocked_consumer_on_unacked_msgs, or the default value if blocked_consumer_on_unacked_msgs is unset.
Sourcepub fn address(&self) -> &str
pub fn address(&self) -> &str
Returns the value of address, or the default value if address is unset.
Sourcepub fn connected_since(&self) -> &str
pub fn connected_since(&self) -> &str
Returns the value of connected_since, or the default value if connected_since is unset.
Sourcepub fn msg_rate_expired(&self) -> f64
pub fn msg_rate_expired(&self) -> f64
Returns the value of msg_rate_expired, or the default value if msg_rate_expired is unset.
Sourcepub fn msg_backlog(&self) -> u64
pub fn msg_backlog(&self) -> u64
Returns the value of msg_backlog, or the default value if msg_backlog is unset.