pub struct CommandError {
pub request_id: u64,
pub error: i32,
pub message: String,
}Fields
request_id: u64error: i32message: StringImplementations
Sourceimpl CommandError
impl CommandError
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.