pub struct CommandLookupTopic {
pub topic: String,
pub request_id: u64,
pub authoritative: Option<bool>,
pub original_principal: Option<String>,
pub original_auth_data: Option<String>,
pub original_auth_method: Option<String>,
pub advertised_listener_name: Option<String>,
}Fields
topic: Stringrequest_id: u64original_principal: Option<String>TODO - Remove original_principal, original_auth_data, original_auth_method Original principal that was verified by a Pulsar proxy.
original_auth_data: Option<String>Original auth role and auth Method that was passed to the proxy.
original_auth_method: Option<String>advertised_listener_name: Option<String>Implementations
Sourceimpl CommandLookupTopic
impl CommandLookupTopic
Returns the value of authoritative, or the default value if authoritative is unset.
Sourcepub fn original_principal(&self) -> &str
pub fn original_principal(&self) -> &str
Returns the value of original_principal, or the default value if original_principal is unset.
Sourcepub fn original_auth_data(&self) -> &str
pub fn original_auth_data(&self) -> &str
Returns the value of original_auth_data, or the default value if original_auth_data is unset.
Sourcepub fn original_auth_method(&self) -> &str
pub fn original_auth_method(&self) -> &str
Returns the value of original_auth_method, or the default value if original_auth_method is unset.
Sourcepub fn advertised_listener_name(&self) -> &str
pub fn advertised_listener_name(&self) -> &str
Returns the value of advertised_listener_name, or the default value if advertised_listener_name is unset.