pub struct CommandLookupTopicResponse {
pub broker_service_url: Option<String>,
pub broker_service_url_tls: Option<String>,
pub response: Option<i32>,
pub request_id: u64,
pub authoritative: Option<bool>,
pub error: Option<i32>,
pub message: Option<String>,
pub proxy_through_service_url: Option<bool>,
}Fields
broker_service_url: Option<String>Optional in case of error
broker_service_url_tls: Option<String>response: Option<i32>request_id: u64error: Option<i32>message: Option<String>proxy_through_service_url: Option<bool>If it’s true, indicates to the client that it must always connect through the service url after the lookup has been completed.
Implementations
Sourceimpl CommandLookupTopicResponse
impl CommandLookupTopicResponse
Sourcepub fn broker_service_url(&self) -> &str
pub fn broker_service_url(&self) -> &str
Returns the value of broker_service_url, or the default value if broker_service_url is unset.
Sourcepub fn broker_service_url_tls(&self) -> &str
pub fn broker_service_url_tls(&self) -> &str
Returns the value of broker_service_url_tls, or the default value if broker_service_url_tls is unset.
Sourcepub fn response(&self) -> LookupType
pub fn response(&self) -> LookupType
Returns the enum value of response, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_response(&mut self, value: LookupType)
pub fn set_response(&mut self, value: LookupType)
Sets response to the provided enum value.
Returns the value of authoritative, or the default value if authoritative is unset.
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn proxy_through_service_url(&self) -> bool
pub fn proxy_through_service_url(&self) -> bool
Returns the value of proxy_through_service_url, or the default value if proxy_through_service_url is unset.