pub struct CommandPartitionedTopicMetadataResponse {
pub partitions: Option<u32>,
pub request_id: u64,
pub response: Option<i32>,
pub error: Option<i32>,
pub message: Option<String>,
}Fields
partitions: Option<u32>Optional in case of error
request_id: u64response: Option<i32>error: Option<i32>message: Option<String>Implementations
Sourceimpl CommandPartitionedTopicMetadataResponse
impl CommandPartitionedTopicMetadataResponse
Sourcepub fn partitions(&self) -> u32
pub fn partitions(&self) -> u32
Returns the value of partitions, or the default value if partitions is unset.
Sourcepub fn response(&self) -> LookupType
pub fn response(&self) -> LookupType
Returns the enum value of response, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_response(&mut self, value: LookupType)
pub fn set_response(&mut self, value: LookupType)
Sets response to the provided enum value.
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.