pub struct CommandProducer {
pub topic: String,
pub producer_id: u64,
pub request_id: u64,
pub producer_name: Option<String>,
pub encrypted: Option<bool>,
pub metadata: Vec<KeyValue>,
pub schema: Option<Schema>,
pub epoch: Option<u64>,
pub user_provided_producer_name: Option<bool>,
}Fields
topic: Stringproducer_id: u64request_id: u64producer_name: Option<String>encrypted: Option<bool>metadata: Vec<KeyValue>schema: Option<Schema>epoch: Option<u64>If producer reconnect to broker, the epoch of this producer will +1
user_provided_producer_name: Option<bool>Indicate the name of the producer is generated or user provided Use default true here is in order to be forward compatible with the client
Implementations
Sourceimpl CommandProducer
impl CommandProducer
Sourcepub fn producer_name(&self) -> &str
pub fn producer_name(&self) -> &str
Returns the value of producer_name, or the default value if producer_name is unset.
Sourcepub fn encrypted(&self) -> bool
pub fn encrypted(&self) -> bool
Returns the value of encrypted, or the default value if encrypted is unset.
Sourcepub fn user_provided_producer_name(&self) -> bool
pub fn user_provided_producer_name(&self) -> bool
Returns the value of user_provided_producer_name, or the default value if user_provided_producer_name is unset.