pub struct CommandProducerSuccess {
pub request_id: u64,
pub producer_name: String,
pub last_sequence_id: Option<i64>,
pub schema_version: Option<Vec<u8>>,
}Fields
request_id: u64producer_name: Stringlast_sequence_id: Option<i64>The last sequence id that was stored by this producer in the previous session This will only be meaningful if deduplication has been enabled.
schema_version: Option<Vec<u8>>Implementations
Sourceimpl CommandProducerSuccess
impl CommandProducerSuccess
Sourcepub fn last_sequence_id(&self) -> i64
pub fn last_sequence_id(&self) -> i64
Returns the value of last_sequence_id, or the default value if last_sequence_id is unset.
Sourcepub fn schema_version(&self) -> &[u8] ⓘ
pub fn schema_version(&self) -> &[u8] ⓘ
Returns the value of schema_version, or the default value if schema_version is unset.