pub struct CommandSendError {
pub producer_id: u64,
pub sequence_id: u64,
pub error: i32,
pub message: String,
}Fields
producer_id: u64sequence_id: u64error: i32message: StringImplementations
Sourceimpl CommandSendError
impl CommandSendError
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.