pub struct CommandTcClientConnectResponse {
pub request_id: u64,
pub error: Option<i32>,
pub message: Option<String>,
}Fields
request_id: u64error: Option<i32>message: Option<String>Implementations
Sourceimpl CommandTcClientConnectResponse
impl CommandTcClientConnectResponse
Sourcepub fn error(&self) -> ServerError
pub fn error(&self) -> ServerError
Returns the enum value of error, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error(&mut self, value: ServerError)
pub fn set_error(&mut self, value: ServerError)
Sets error to the provided enum value.