pub struct SingleMessageMetadata {
pub properties: Vec<KeyValue>,
pub partition_key: Option<String>,
pub payload_size: i32,
pub compacted_out: Option<bool>,
pub event_time: Option<u64>,
pub partition_key_b64_encoded: Option<bool>,
pub ordering_key: Option<Vec<u8>>,
pub sequence_id: Option<u64>,
pub null_value: Option<bool>,
pub null_partition_key: Option<bool>,
}Fields
properties: Vec<KeyValue>partition_key: Option<String>payload_size: i32compacted_out: Option<bool>event_time: Option<u64>the timestamp that this event occurs. it is typically set by applications.
if this field is omitted, publish_time can be used for the purpose of event_time.
partition_key_b64_encoded: Option<bool>ordering_key: Option<Vec<u8>>Specific a key to overwrite the message key which used for ordering dispatch in Key_Shared mode.
sequence_id: Option<u64>Allows consumer retrieve the sequence id that the producer set.
null_value: Option<bool>Indicate if the message payload value is set
null_partition_key: Option<bool>Indicate if the message partition key is set
Implementations
Sourceimpl SingleMessageMetadata
impl SingleMessageMetadata
Sourcepub fn partition_key(&self) -> &str
pub fn partition_key(&self) -> &str
Returns the value of partition_key, or the default value if partition_key is unset.
Sourcepub fn compacted_out(&self) -> bool
pub fn compacted_out(&self) -> bool
Returns the value of compacted_out, or the default value if compacted_out is unset.
Sourcepub fn event_time(&self) -> u64
pub fn event_time(&self) -> u64
Returns the value of event_time, or the default value if event_time is unset.
Sourcepub fn partition_key_b64_encoded(&self) -> bool
pub fn partition_key_b64_encoded(&self) -> bool
Returns the value of partition_key_b64_encoded, or the default value if partition_key_b64_encoded is unset.
Sourcepub fn ordering_key(&self) -> &[u8] ⓘ
pub fn ordering_key(&self) -> &[u8] ⓘ
Returns the value of ordering_key, or the default value if ordering_key is unset.
Sourcepub fn sequence_id(&self) -> u64
pub fn sequence_id(&self) -> u64
Returns the value of sequence_id, or the default value if sequence_id is unset.
Sourcepub fn null_value(&self) -> bool
pub fn null_value(&self) -> bool
Returns the value of null_value, or the default value if null_value is unset.
Sourcepub fn null_partition_key(&self) -> bool
pub fn null_partition_key(&self) -> bool
Returns the value of null_partition_key, or the default value if null_partition_key is unset.