pub struct Message {
pub command: BaseCommand,
pub payload: Option<Payload>,
}Expand description
Pulsar binary message
this structure holds any command sent to pulsar, like looking up a topic or subscribing on a topic
Fields
command: BaseCommandBasic pulsar command, as defined in Pulsar’s protobuf file
payload: Option<Payload>payload for topic messages
Implementations