[][src]Struct pulsar::ServiceDiscovery

pub struct ServiceDiscovery<Exe: Executor + ?Sized> { /* fields omitted */ }

Look up broker addresses for topics and partitioned topics

The ServiceDiscovery object provides a single interface to start interacting with a cluster. It will automatically follow redirects or use a proxy, and aggregate broker connections

Implementations

impl<Exe: Executor> ServiceDiscovery<Exe>[src]

pub fn with_manager(manager: Arc<ConnectionManager<Exe>>) -> Self[src]

pub async fn lookup_topic<'_, S: Into<String>>(
    &'_ self,
    topic: S
) -> Result<BrokerAddress, ServiceDiscoveryError>
[src]

get the broker address for a topic

pub async fn lookup_partitioned_topic_number<'_, S: Into<String>>(
    &'_ self,
    topic: S
) -> Result<u32, ServiceDiscoveryError>
[src]

get the number of partitions for a partitioned topic

pub async fn lookup_partitioned_topic<'_, S: Into<String>>(
    &'_ self,
    topic: S
) -> Result<Vec<(String, BrokerAddress)>, ServiceDiscoveryError>
[src]

get the list of topic names and addresses for a partitioned topic