ProtocolVersion

Enum ProtocolVersion 

#[repr(i32)]
pub enum ProtocolVersion {
Show 20 variants V0 = 0, V1 = 1, V2 = 2, V3 = 3, V4 = 4, V5 = 5, V6 = 6, V7 = 7, V8 = 8, V9 = 9, V10 = 10, V11 = 11, V12 = 12, V13 = 13, V14 = 14, V15 = 15, V16 = 16, V17 = 17, V18 = 18, V19 = 19,
}
Each protocol version identify new features that are incrementally added to the protocol

Variants



V0 = 0

Initial versioning



V1 = 1

Added application keep-alive



V2 = 2

Added RedeliverUnacknowledgedMessages Command



V3 = 3

Added compression with LZ4 and ZLib



V4 = 4

Added batch message support



V5 = 5

Added disconnect client w/o closing connection



V6 = 6

Added checksum computation for metadata + payload



V7 = 7

Added CommandLookupTopic - Binary Lookup



V8 = 8

Added CommandConsumerStats - Client fetches broker side consumer stats



V9 = 9

Added end of topic notification



V10 = 10

Added proxy to broker



V11 = 11

C++ consumers before this version are not correctly handling the checksum field



V12 = 12

Added get topic’s last messageId from broker



V13 = 13

Added CommandActiveConsumerChange Added CommandGetTopicsOfNamespace

Schema-registry : added avro schema format for json



V14 = 14

Add CommandAuthChallenge and CommandAuthResponse for mutual auth



V15 = 15

Added Key_Shared subscription

Add CommandGetOrCreateSchema and CommandGetOrCreateSchemaResponse



V16 = 16

Add support for broker entry metadata



V17 = 17

Added support ack receipt



V18 = 18

Add client support for broker entry metadata



V19 = 19

Add CommandTcClientConnectRequest and CommandTcClientConnectResponse

Implementations

Source

impl ProtocolVersion

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ProtocolVersion.

pub fn from_i32(value: i32) -> Option<ProtocolVersion>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a ProtocolVersion, or None if value is not a valid variant.

Source

impl ProtocolVersion

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.