[][src]Struct pulsar::message::proto::CommandLookupTopicResponse

pub struct CommandLookupTopicResponse {
    pub broker_service_url: Option<String>,
    pub broker_service_url_tls: Option<String>,
    pub response: Option<i32>,
    pub request_id: u64,
    pub authoritative: Option<bool>,
    pub error: Option<i32>,
    pub message: Option<String>,
    pub proxy_through_service_url: Option<bool>,
}

Fields

broker_service_url: Option<String>

Optional in case of error

broker_service_url_tls: Option<String>response: Option<i32>request_id: u64authoritative: Option<bool>error: Option<i32>message: Option<String>proxy_through_service_url: Option<bool>

If it's true, indicates to the client that it must always connect through the service url after the lookup has been completed.

Implementations

impl CommandLookupTopicResponse[src]

pub fn broker_service_url(&self) -> &str[src]

Returns the value of broker_service_url, or the default value if broker_service_url is unset.

pub fn broker_service_url_tls(&self) -> &str[src]

Returns the value of broker_service_url_tls, or the default value if broker_service_url_tls is unset.

pub fn response(&self) -> LookupType[src]

Returns the enum value of response, or the default if the field is unset or set to an invalid enum value.

pub fn set_response(&mut self, value: LookupType)[src]

Sets response to the provided enum value.

pub fn authoritative(&self) -> bool[src]

Returns the value of authoritative, or the default value if authoritative is unset.

pub fn error(&self) -> ServerError[src]

Returns the enum value of error, or the default if the field is unset or set to an invalid enum value.

pub fn set_error(&mut self, value: ServerError)[src]

Sets error to the provided enum value.

pub fn message(&self) -> &str[src]

Returns the value of message, or the default value if message is unset.

pub fn proxy_through_service_url(&self) -> bool[src]

Returns the value of proxy_through_service_url, or the default value if proxy_through_service_url is unset.