[][src]Struct pulsar::message::proto::CommandPartitionedTopicMetadata

pub struct CommandPartitionedTopicMetadata {
    pub topic: String,
    pub request_id: u64,
    pub original_principal: Option<String>,
    pub original_auth_data: Option<String>,
    pub original_auth_method: Option<String>,
}

Fields

topic: Stringrequest_id: u64original_principal: Option<String>

TODO - Remove original_principal, original_auth_data, original_auth_method Original principal that was verified by a Pulsar proxy.

original_auth_data: Option<String>

Original auth role and auth Method that was passed to the proxy.

original_auth_method: Option<String>

Implementations

impl CommandPartitionedTopicMetadata[src]

pub fn original_principal(&self) -> &str[src]

Returns the value of original_principal, or the default value if original_principal is unset.

pub fn original_auth_data(&self) -> &str[src]

Returns the value of original_auth_data, or the default value if original_auth_data is unset.

pub fn original_auth_method(&self) -> &str[src]

Returns the value of original_auth_method, or the default value if original_auth_method is unset.